@@ -1,4 +1,6 @@
 use std::{error, fmt, io};
+use quick_xml::escape::EscapeError;
+use quick_xml::encoding::EncodingError;
 
 #[cfg(feature = "serde")]
 use crate::stream::Event;
@@ -193,6 +195,18 @@ impl From<InvalidXmlDate> for ErrorKind {
     }
 }
 
+impl From<EscapeError> for ErrorKind {
+    fn from(_: EscapeError) -> Self {
+        ErrorKind::InvalidXmlUtf8
+    }
+}
+
+impl From<EncodingError> for ErrorKind {
+    fn from(_: EncodingError) -> Self {
+        ErrorKind::InvalidXmlUtf8
+    }
+}
+
 impl EventKind {
     #[cfg(feature = "serde")]
     pub fn of_event(event: &Event) -> EventKind {
