@@ -8,7 +8,8 @@ use std::{
 use crate::{
     error::{self, Error, ErrorKind, EventKind},
     stream::{
-        private, BinaryWriter, Event, Events, Reader, Writer, XmlReader, XmlWriteOptions, XmlWriter,
+        private, AsciiReader, BinaryWriter, Event, Events, Reader, Writer, XmlReader,
+        XmlWriteOptions, XmlWriter,
     },
     u64_to_usize, Date, Dictionary, Integer, Uid,
 };
@@ -41,9 +42,15 @@ impl Value {
         Value::from_events(reader)
     }
 
-    /// Reads a `Value` from a seekable byte stream containing an XML encoded plist.
+    /// Reads a `Value` from a byte stream containing an ASCII encoded plist.
+    pub fn from_reader_ascii<R: Read>(reader: R) -> Result<Value, Error> {
+        let reader = AsciiReader::new(reader);
+        Value::from_events(reader)
+    }
+
+    /// Reads a `Value` from a byte stream containing an XML encoded plist.
     pub fn from_reader_xml<R: Read>(reader: R) -> Result<Value, Error> {
-        let reader = XmlReader::new(reader);
+        let reader = XmlReader::new(BufReader::new(reader));
         Value::from_events(reader)
     }
 
@@ -134,19 +141,19 @@ impl Value {
     #[cfg(feature = "enable_unstable_features_that_may_break_with_minor_version_bumps")]
     #[doc(hidden)]
     #[deprecated(since = "1.2.0", note = "use Value::events instead")]
-    pub fn into_events(&self) -> Events {
+    pub fn into_events(&self) -> Events<'_> {
         self.events()
     }
 
     /// Creates an `Event` iterator for this `Value`.
     #[cfg(not(feature = "enable_unstable_features_that_may_break_with_minor_version_bumps"))]
-    pub(crate) fn events(&self) -> Events {
+    pub(crate) fn events(&self) -> Events<'_> {
         Events::new(self)
     }
 
     /// Creates an `Event` iterator for this `Value`.
     #[cfg(feature = "enable_unstable_features_that_may_break_with_minor_version_bumps")]
-    pub fn events(&self) -> Events {
+    pub fn events(&self) -> Events<'_> {
         Events::new(self)
     }
 
@@ -676,7 +683,7 @@ impl Builder {
                 self.stack.push(StackItem::Array(array));
             }
             (Some(StackItem::Dict(dict)), Value::String(key)) => {
-                self.stack.push(StackItem::DictAndKey(dict, key))
+                self.stack.push(StackItem::DictAndKey(dict, key));
             }
             (Some(StackItem::Dict(_)), value) => {
                 return Err(ErrorKind::UnexpectedEventType {
@@ -770,7 +777,7 @@ mod tests {
     use std::time::SystemTime;
 
     use super::*;
-    use crate::{stream::Event::*, Date, Dictionary, Value};
+    use crate::{stream::Event::*, Date};
 
     #[test]
     fn value_accessors() {
@@ -795,14 +802,14 @@ mod tests {
         );
 
         let date: Date = SystemTime::now().into();
-        assert_eq!(Value::Date(date.clone()).as_date(), Some(date));
+        assert_eq!(Value::Date(date).as_date(), Some(date));
 
         assert_eq!(Value::Real(0.0).as_real(), Some(0.0));
         assert_eq!(Value::Integer(1.into()).as_signed_integer(), Some(1));
         assert_eq!(Value::Integer(1.into()).as_unsigned_integer(), Some(1));
         assert_eq!(Value::Integer((-1).into()).as_unsigned_integer(), None);
         assert_eq!(
-            Value::Integer((i64::max_value() as u64 + 1).into()).as_signed_integer(),
+            Value::Integer((i64::MAX as u64 + 1).into()).as_signed_integer(),
             None
         );
         assert_eq!(Value::String("2".to_owned()).as_string(), Some("2"));
@@ -831,7 +838,7 @@ mod tests {
             EndCollection,
         ];
 
-        let value = Builder::build(events.into_iter().map(|e| Ok(e)));
+        let value = Builder::build(events.into_iter().map(Ok));
 
         // Expected output
         let lines = vec![
@@ -850,4 +857,13 @@ mod tests {
 
         assert_eq!(value.unwrap(), Value::Dictionary(dict));
     }
+
+    #[test]
+    fn builder_fails_if_all_events_have_not_been_read() {
+        let events = vec![String("Item 1".into()), String("Item 2".into())];
+
+        let value = Builder::build(events.into_iter().map(Ok));
+
+        assert!(value.is_err());
+    }
 }
